// with T sensor DS18B20 
// tested on Arduino Nano, IDE 1.8.13

#include <LiquidCrystal.h>
#include <OneWire.h> 
#include <DallasTemperature.h>
#define BACKLIGHT 10
// Data wire is plugged into pin 6 on the Arduino 
#define ONE_WIRE_BUS 6
/********************************************************************/
// Setup a oneWire instance to communicate with any OneWire devices  
// (not just Maxim/Dallas temperature ICs) 
OneWire oneWire(ONE_WIRE_BUS); 
/********************************************************************/
// Pass our oneWire reference to Dallas Temperature. 
DallasTemperature sensors(&oneWire);
/********************************************************************/ 

boolean blacklightStatus = false;
//LiquidCrystal lcd(RS, E, D4, D5, D6, D7);
LiquidCrystal lcd(12,11,5,4,3,2);

void setup() {
  Serial.begin(9600);
  sensors.begin();
  pinMode(8, OUTPUT); // to connect 
  pinMode(A0, INPUT); // T sensor DS18B20 
  pinMode(A2, INPUT); // potenziometer to set Delta
  pinMode(A4, INPUT); // potenziometer to set T min
  lcd.begin(16, 2);
  delay(200);
}

int thermostat; 
int TminPot; 
int DeltaPot; 
float temperature; 
float Tmin; 
float Delta; 

void myInputs() {
  delay(50); 
  thermostat = analogRead(A0); 
  delay(50); 
  TminPot = 1023 - analogRead(A4); 
  delay(50); 
  DeltaPot = 1023 - analogRead(A2); 
  delay(50);
  sensors.requestTemperatures(); 
  delay(50);
}

void loop() {
  myInputs(); 
  temperature = int(sensors.getTempCByIndex(0)*10.)/10.;
  Tmin = int(TminPot/1023.*1000. + 0.)/10.;  // to trasform the first potenziometer reading in Tmin     (float from 0.0 to 100.0) 
  Delta = int(DeltaPot/1023.*100.)/10.;      // to trasform the second potenziometer reading in "Delta" (float from 0.0 to  10.0)
  //Serial.print(" temperature = "); // for testing during calibration 
  //Serial.println(temperature);
  lcd.setCursor(0,0);
  lcd.print("   T = ");
  lcd.print(temperature);
  lcd.print(" C ");
  //Serial.print(sensors.getTempCByIndex(0)); // for testing during calibration 
  //lcd.print(sensors.getTempCByIndex(0));   
  lcd.print("  "); 
  lcd.setCursor(0,1);
  lcd.print("Tm=");
  lcd.print(Tmin);   
  lcd.print("  D=");
  lcd.print(Delta);   
  lcd.print("  ");
  delay(50); 
  if (temperature < Tmin) { // if T < T min, the relais switches ON
     digitalWrite(8, HIGH); 
  }
  if (temperature > Tmin + Delta) { // if T > T min + Delta, the Relais switches OFF
     digitalWrite(8, LOW); 
  }
  delay(100); 
}
